pub trait ClassInfoMethods: WxRustMethods {
// Provided methods
fn create_object(&self) -> Option<ObjectIsOwned<false>> { ... }
fn get_base_class_name1(&self) -> *const c_void { ... }
fn get_base_class_name2(&self) -> *const c_void { ... }
fn get_class_name(&self) -> *const c_void { ... }
fn get_size(&self) -> c_int { ... }
fn is_dynamic(&self) -> bool { ... }
fn is_kind_of<C: ClassInfoMethods>(&self, info: Option<&C>) -> bool { ... }
fn find_class(class_name: &str) -> Option<ClassInfoIsOwned<false>> { ... }
}Expand description
This trait represents C++ wxClassInfo class’s methods and inheritance.
See ClassInfoIsOwned documentation for the class usage.
Provided Methods
Sourcefn create_object(&self) -> Option<ObjectIsOwned<false>>
fn create_object(&self) -> Option<ObjectIsOwned<false>>
Creates an object of the appropriate kind.
Sourcefn get_base_class_name1(&self) -> *const c_void
fn get_base_class_name1(&self) -> *const c_void
Returns the name of the first base class (NULL if none).
Sourcefn get_base_class_name2(&self) -> *const c_void
fn get_base_class_name2(&self) -> *const c_void
Returns the name of the second base class (NULL if none).
Sourcefn get_class_name(&self) -> *const c_void
fn get_class_name(&self) -> *const c_void
Returns the string form of the class name.
Sourcefn is_dynamic(&self) -> bool
fn is_dynamic(&self) -> bool
Returns true if this class info can create objects of the associated class.
Sourcefn is_kind_of<C: ClassInfoMethods>(&self, info: Option<&C>) -> bool
fn is_kind_of<C: ClassInfoMethods>(&self, info: Option<&C>) -> bool
Returns true if this class is a kind of (inherits from) the given class.
Sourcefn find_class(class_name: &str) -> Option<ClassInfoIsOwned<false>>
fn find_class(class_name: &str) -> Option<ClassInfoIsOwned<false>>
Finds the wxClassInfo object for a class with the given name.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".