pub trait RefCounterMethods: WxRustMethods {
// Provided methods
fn dec_ref(&self) { ... }
fn get_ref_count(&self) -> c_int { ... }
fn inc_ref(&self) { ... }
}Expand description
This trait represents C++ wxRefCounter class’s methods and inheritance.
See RefCounterIsOwned documentation for the class usage.
Provided Methods
Sourcefn dec_ref(&self)
fn dec_ref(&self)
Decrements the reference count associated with this shared data and, if it reaches zero, destroys this instance of wxRefCounter releasing its memory.
Sourcefn get_ref_count(&self) -> c_int
fn get_ref_count(&self) -> c_int
Returns the reference count associated with this shared data.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".