pub trait StandardPathsMethods: WxRustMethods {
Show 20 methods
// Provided methods
fn dont_ignore_app_sub_dir(&self) { ... }
fn get_app_documents_dir(&self) -> String { ... }
fn get_config_dir(&self) -> String { ... }
fn get_data_dir(&self) -> String { ... }
fn get_documents_dir(&self) -> String { ... }
fn get_executable_path(&self) -> String { ... }
fn get_install_prefix(&self) -> String { ... }
fn get_local_data_dir(&self) -> String { ... }
fn get_plugins_dir(&self) -> String { ... }
fn get_resources_dir(&self) -> String { ... }
fn get_temp_dir(&self) -> String { ... }
fn get_user_config_dir(&self) -> String { ... }
fn get_user_data_dir(&self) -> String { ... }
fn get_user_local_data_dir(&self) -> String { ... }
fn ignore_app_sub_dir(&self, subdir_pattern: &str) { ... }
fn ignore_app_build_sub_dirs(&self) { ... }
fn set_install_prefix(&self, prefix: &str) { ... }
fn use_app_info(&self, info: c_int) { ... }
fn get() -> StandardPathsIsOwned<false> { ... }
fn msw_get_shell_dir(csidl: c_int) -> String { ... }
}Expand description
This trait represents C++ wxStandardPaths class’s methods and inheritance.
See StandardPathsIsOwned documentation for the class usage.
Provided Methods
Sourcefn dont_ignore_app_sub_dir(&self)
fn dont_ignore_app_sub_dir(&self)
MSW-specific function undoing the effect of IgnoreAppSubDir() calls.
See C++ wxStandardPaths::DontIgnoreAppSubDir()’s documentation.
Sourcefn get_app_documents_dir(&self) -> String
fn get_app_documents_dir(&self) -> String
Return the directory for the document files used by this application.
See C++ wxStandardPaths::GetAppDocumentsDir()’s documentation.
Sourcefn get_config_dir(&self) -> String
fn get_config_dir(&self) -> String
Return the directory containing the system config files.
Sourcefn get_data_dir(&self) -> String
fn get_data_dir(&self) -> String
Return the location of the applications global, i.e. not user-specific, data files.
Sourcefn get_documents_dir(&self) -> String
fn get_documents_dir(&self) -> String
Same as calling GetUserDir() with Dir_Documents parameter.
Sourcefn get_executable_path(&self) -> String
fn get_executable_path(&self) -> String
Return the directory and the filename for the current executable.
See C++ wxStandardPaths::GetExecutablePath()’s documentation.
Sourcefn get_install_prefix(&self) -> String
fn get_install_prefix(&self) -> String
Return the program installation prefix, e.g. /usr, /opt or /home/zeitlin.
See C++ wxStandardPaths::GetInstallPrefix()’s documentation.
Sourcefn get_local_data_dir(&self) -> String
fn get_local_data_dir(&self) -> String
Return the location for application data files which are host-specific and can’t, or shouldn’t, be shared with the other machines.
Sourcefn get_plugins_dir(&self) -> String
fn get_plugins_dir(&self) -> String
Return the directory where the loadable modules (plugins) live.
Sourcefn get_resources_dir(&self) -> String
fn get_resources_dir(&self) -> String
Return the directory where the application resource files are located.
Sourcefn get_temp_dir(&self) -> String
fn get_temp_dir(&self) -> String
Return the directory for storing temporary files, for the current user.
Sourcefn get_user_config_dir(&self) -> String
fn get_user_config_dir(&self) -> String
Return the directory for the user config files.
See C++ wxStandardPaths::GetUserConfigDir()’s documentation.
Sourcefn get_user_data_dir(&self) -> String
fn get_user_data_dir(&self) -> String
Return the directory for the user-dependent application data files:
Sourcefn get_user_local_data_dir(&self) -> String
fn get_user_local_data_dir(&self) -> String
Return the directory for user data files which shouldn’t be shared with the other machines.
See C++ wxStandardPaths::GetUserLocalDataDir()’s documentation.
Sourcefn ignore_app_sub_dir(&self, subdir_pattern: &str)
fn ignore_app_sub_dir(&self, subdir_pattern: &str)
MSW-specific function to customize application directory detection.
Sourcefn ignore_app_build_sub_dirs(&self)
fn ignore_app_build_sub_dirs(&self)
MSW-specific function to ignore all common build directories.
See C++ wxStandardPaths::IgnoreAppBuildSubDirs()’s documentation.
Sourcefn set_install_prefix(&self, prefix: &str)
fn set_install_prefix(&self, prefix: &str)
Lets wxStandardPaths know about the real program installation prefix on a Unix system.
See C++ wxStandardPaths::SetInstallPrefix()’s documentation.
Sourcefn use_app_info(&self, info: c_int)
fn use_app_info(&self, info: c_int)
Controls what application information is used when constructing paths that should be unique to this program, such as the application data directory, the plugins directory on Unix, etc.
Sourcefn get() -> StandardPathsIsOwned<false>
fn get() -> StandardPathsIsOwned<false>
Returns reference to the unique global standard paths object.
Sourcefn msw_get_shell_dir(csidl: c_int) -> String
fn msw_get_shell_dir(csidl: c_int) -> String
Returns location of Windows shell special folder.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".