pub trait VariantDataMethods: ObjectRefDataMethods {
// Provided methods
fn clone(&self) -> Option<VariantDataIsOwned<false>> { ... }
fn dec_ref(&self) { ... }
fn eq<V: VariantDataMethods>(&self, data: &V) -> bool { ... }
fn get_type(&self) -> String { ... }
fn get_value_class_info(&self) -> Option<ClassInfoIsOwned<false>> { ... }
fn inc_ref(&self) { ... }
fn read(&self, string: *mut c_void) -> bool { ... }
fn write(&self, string: *mut c_void) -> bool { ... }
}Expand description
This trait represents C++ wxVariantData class’s methods and inheritance.
See VariantDataIsOwned documentation for the class usage.
Provided Methods
Sourcefn clone(&self) -> Option<VariantDataIsOwned<false>>
fn clone(&self) -> Option<VariantDataIsOwned<false>>
This function can be overridden to clone the data.
Sourcefn eq<V: VariantDataMethods>(&self, data: &V) -> bool
fn eq<V: VariantDataMethods>(&self, data: &V) -> bool
Returns true if this object is equal to data.
Sourcefn get_value_class_info(&self) -> Option<ClassInfoIsOwned<false>>
fn get_value_class_info(&self) -> Option<ClassInfoIsOwned<false>>
If the data is a wxObject returns a pointer to the objects wxClassInfo structure, if the data isn’t a wxObject the method returns NULL.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".