StandardPaths

Type Alias StandardPaths 

pub type StandardPaths = StandardPathsIsOwned<true>;
wxStandardPaths returns the standard locations in the file system and should be used by applications to find their data files in a portable way.

Aliased Type

pub struct StandardPaths(/* private fields */);