pub type StandardPaths = StandardPathsIsOwned<true>;Expand description
wxStandardPaths returns the standard locations in the file system and should be used by applications to find their data files in a portable way.
StandardPathsrepresents a C++wxStandardPathsclass instance which your code has ownership,StandardPathsIsOwned<false>represents one which don’t own.- Use
StandardPaths’snew()to create an instance of this class. - See C++
wxStandardPathsclass’s documentation for more details.
Aliased Type
pub struct StandardPaths(/* private fields */);